@@ -62,7 +62,9 @@
 (-246.000, -179.000)
 """
 
-__version__ = '1.3.1'
+import os.path
+
+__version__ = open(os.path.join(os.path.dirname(__file__), 'VERSION')).read().strip()
 
 import sys
 import urllib
@@ -76,15 +78,18 @@ import time
 try:
     import Image
 except ImportError:
-    # you need PIL to do any actual drawing, but
-    # maybe that's not what you're using MMaps for?
-    import PIL.Image as Image
+    try:
+        import PIL.Image as Image
+    except ImportError:
+        # you need PIL to do any actual drawing, but
+        # maybe that's not what you're using MMaps for?
+        Image = None
 
 import Tiles
 import Providers
 import Core
 import Geo
-import Yahoo, Microsoft, BlueMarble, OpenStreetMap, CloudMade, MapQuest
+import Yahoo, Microsoft, BlueMarble, OpenStreetMap, CloudMade, MapQuest, Stamen
 import time
 
 # a handy list of possible providers, which isn't
@@ -106,7 +111,10 @@ builtinProviders = {
     'CLOUDMADE_TOURIST': CloudMade.TouristProvider,
     'CLOUDMADE_FRESH':  CloudMade.FreshProvider,
     'CLOUDMADE_PALEDAWN': CloudMade.PaleDawnProvider,
-    'CLOUDMADE_MIDNIGHTCOMMANDER': CloudMade.MidnightCommanderProvider
+    'CLOUDMADE_MIDNIGHTCOMMANDER': CloudMade.MidnightCommanderProvider,
+    'STAMEN_TONER': Stamen.TonerProvider,
+    'STAMEN_TERRAIN': Stamen.TerrainProvider,
+    'STAMEN_WATERCOLOR': Stamen.WatercolorProvider,
     }
 
 def mapByCenterZoom(provider, center, zoom, dimensions):
